@@ -8,6 +8,8 @@ Test::Locale::Utils - utilities for writing tests involving international charac
 
 =head1 SYNOPSIS
 
+### TODO revise
+
    use Test::More;
    use Test::Locale::Utils qw(:all);
    my @exchars = extract_extended_chars(\@strings);
@@ -17,14 +19,13 @@ Test::Locale::Utils - utilities for writing tests involving international charac
 
    foreach my $string (@strings) {
       SKIP: {
-         skip "This locale can't deal with i18n chars in string: $string", 1, 
+         skip "This locale can't deal with i18n chars in string: $string", 1,
              unless ($internat && ($string =~ /$exchars_rule/) );
 
          is( $expected{$string}, string_transformation($string), "Testing $string" );
       }
    }
 
-
 =head1 DESCRIPTION
 
 A small collection of utility functions to make it easier to
@@ -34,38 +35,32 @@ beyond the 7bit ASCII range (e.g. the "extended characters" or
 
 =head1 EXPORTED
 
-Nothing by default.  All of the following are exportable 
+Nothing by default.  All of the following are exportable
 on request (and all may be requested with the ":all" tag).
 
-=over 
+=over
 
-=cut 
+=cut
 
 use 5.006;
-use strict; 
+use strict;
 use warnings;
 use Carp;
 use Data::Dumper;
-my $DEBUG = 1;
+use List::MoreUtils qw( all );
+
+my $DEBUG = 0;
 
 require Exporter;
 
 our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Test::Locale::Utils ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
   extract_extended_chars
   internationalized_locale
+  is_locale_international
+  define_sample_i18n_chars
 ) ] );
-
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
 our @EXPORT = qw(  );
 
 our $VERSION = '0.01';
@@ -76,12 +71,12 @@ Given a reference to an array of strings, returns a list of all
 extended characters that have appeared at least once in the
 strings.
 
-=cut 
+=cut
 
 sub extract_extended_chars  {
     my $aref = shift;
 
-    my $sevenbit_rule = qr{[\x00-\x7F]}; 
+    my $sevenbit_rule = qr{[\x00-\x7F]};
 
     my %seen;
     foreach my $string ( @{$aref} ) {
@@ -95,12 +90,22 @@ sub extract_extended_chars  {
 
 =item  internationalized_locale
 
-Given an array of extended characters that you care about, 
-this code will check to make sure that the current locale 
-seems to comprehend what to do with them.  Specifically, 
+DEPRECATED.
+
+Given an array of extended characters that you care about,
+this code will check to make sure that the current locale
+seems to comprehend what to do with them.  Specifically,
 it checks to see if they have a defined upper and lower case.
 
-=cut 
+This is an excessively simple version that just looks at the
+extended characters to see if they change case when run through
+either uc or lc.
+
+This apparently fails for some locales, e.g. Russian, where the
+extended chars are in the same locations as in iso8859, but the
+upper and lower have reversed positions.
+
+=cut
 
 sub internationalized_locale {
   my @exchars = @_;
@@ -111,22 +116,90 @@ sub internationalized_locale {
     my $up = uc($ex);
     my $down = lc($ex);
     if ($up eq $down) { # then we got problems
-      warn "For this locale, uppercase and lowercase not defined for $ex\n";
+      warn "For this locale, uppercase and lowercase not defined for $ex\n" if $DEBUG;
       $okay = 0;
     }
   }
   return $okay;
 }
 
+
+=item  is_locale_international
+
+Looks at the behavior of uc and lc with a small sample of
+international characters: this just checks if the "extended
+characters" of latin-1 and friends have an upper and lower form
+defined as expected.
+
+=cut
+
+sub is_locale_international {
+  my $exchars = define_sample_i18n_chars();
+  use locale;
+
+  my @checks;
+  foreach my $pair ( @{ $exchars } ) {
+    my $lower = $pair->[0];
+    my $upper = $pair->[1];
+
+    my $new_up   = uc($lower);
+    my $new_down = lc($upper);
+
+    if ( ($upper eq $new_up)   &&
+         ($lower eq $new_down) ) { # transformed as expected
+      push @checks, 1;
+    } else {
+      push @checks, 0;
+    }
+  }
+  print STDERR "internationalized_locale: char status: ",
+    join " ", @checks, "\n" if ($DEBUG) ;
+  my $okay = all { ($_) } @checks;
+  return $okay;
+}
+
+
+=item define_sample_i18n_chars
+
+Returns a short list of pairs of extended characters,
+pairing a lowercase form with an uppercase one
+(an aref of arefs).
+
+=cut
+
+sub define_sample_i18n_chars {
+
+  my @exchars = (
+                ['', ''],
+                ['', ''],
+                ['', ''],
+                ['', ''],
+              );
+
+  return \@exchars;
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
 1;
 __END__
 
 =back
 
-=head1 DISCUSSION 
+=head1 DISCUSSION
 
-The "use locale" story seems to have some notable gaps. 
-A brief summary, off the top of my head: 
+The "use locale" story seems to have some notable gaps.
+A brief summary, off the top of my head:
 
 There's no definitive way to get a listing of all available
 locales on a system.  The right way to do it varies from platform
@@ -138,12 +211,12 @@ cases like "cygwin").  There's no definitive list of all possible
 values of ^O (or if there is, I have not been able to discover
 it).  There are some useful tricks in the POSIX module that can
 help with these issues, but you can't count on every system that
-perl runs on being POSIX compliant, (and like I just said, 
-checking what kind of platform you're on is a little trickier 
+perl runs on being POSIX compliant, (and like I just said,
+checking what kind of platform you're on is a little trickier
 than you'd think).
 
-This little module is an attempt at cutting the Gordian Knot 
-represented by this cluster of problems, at least 
+This little module is an attempt at cutting the Gordian Knot
+represented by this cluster of problems, at least
 as far as the automated tests for Text::Capitalize are concerned.
 
 Since it's difficult to determine the Right Way to do
